---
name: Bug report
about: Report any issues found and help us improve
title: 'fix: [ISSUE]'
labels: bug
assignees: ''

---

## Describe the bug
A clear and concise description of what the bug is.

## To reproduce
Steps to reproduce the behavior.

## Expected behavior
A clear and concise description of what you expected to happen.

## Environment details
 - Version: [e.g. 0.41.2]

## Additional context
Add any other context about the problem here.

## Screenshots
If applicable, add screenshots to help explain your problem.
